<%
'the transform_BB() function matches text that has already been through the SQL_encode() function
'if you are adding your own BB codes remeber that you will be matching ASCII characters rather
'than their real text equivalents 

'converts bbCode into html before insertion to the database.
function transform_BB(strContent, intImages)
	
	'check content has been passed
	if isnull(strContent) = false then
		
		'replace code tags
		strContent = replace_format(strContent)
		
		'replace url tags
		strContent = replace_url(strContent)
		
		'check images are enabled
		if intImages = 1 then
			'replace image tags
			strContent = replace_img(strContent)
		end if
		
		'replace quotes
		strContent = replace_quote(strContent)
		
		'replace SQL characters
		strContent = SQL_encode(strContent)
		
		'return transformed content
		transform_BB = strContent
		
	end if
	
end function

'converts html into bbCode for viewing by the user.
function transform_HTML(strContent)
	
	'check content has been passed
	if isnull(strContent) = false then
		
		'decode SQL characters
		strContent = SQL_decode(strContent)	
		
		'replace quote tags
		strContent = revert_quote(strContent)
		
		'replace img tags
		strContent = revert_img(strContent)
		
		'replace url tags
		strContent = revert_url(strContent)
		
		'replace formatting
		strContent = revert_format(strContent)
		
		'replace line breaks
		strContent = replace(strContent, "<br />", vbcrlf)
		
		'return transform content
		transform_HTML = strContent
		
	end if
	
end function

'replaces smilies and carriage returns
function HTML_decode(strContent)
	
	'check content has been passed
	if isnull(strContent) = false then
		
		'decode SQL characters
		strContent = SQL_decode(strContent)	
		
		'replace smilies
		strContent = revert_smilies(strContent)
		
		'replace line breaks
		strContent = replace(strContent, "<br />", vbcrlf)	
		
		'return transformed content
		HTML_decode = strContent
		
	end if
	
end function
	
'count instances of start tags and end tags, if they match return passed.
function tag_count(strContent, intFirst, intLast)

	'dimension variables
	dim intOpen, intClose
	
	intOpen = 0
	intClose = 0
	
	intOpen = ubound(split(strContent, intFirst)) + ubound(split(strContent, lcase(intFirst)))
	intClose = ubound(split(strContent, intLast)) + ubound(split(strContent, lcase(intLast)))
	
	if intOpen = intClose and intOpen > 0 then
		tag_count = "passed"
	else
		tag_count = "failed"
	end if

end function

'replace all text formatting tags with the appropriate html tags
function replace_format(strContent)
	
	'dimension variables
	dim strOpen, strClose
	
	if instr(1, strContent, "[B]", 1) > 0 then
		strOpen = "[B]"
		strClose = "[/B]"	
		if tag_count(strContent, strOpen, strClose) = "passed" then
			strContent = replace(strContent, "[B]", "<b>", 1, -1, 1)
			strContent = replace(strContent, "[/B]", "</b>", 1, -1, 1)
		end if
	end if
	
	if instr(1, strContent, "[I]", 1) > 0 then
		strOpen = "[I]"
		strClose = "[/I]"	
		if tag_count(strContent, strOpen, strClose) = "passed" then
			strContent = replace(strContent, "[I]", "<i>", 1, -1, 1)
			strContent = replace(strContent, "[/I]", "</i>", 1, -1, 1)
		end if
	end if
	
	if instr(1, strContent, "[U]", 1) > 0 then
		strOpen = "[U]"
		strClose = "[/U]"	
		if tag_count(strContent, strOpen, strClose) = "passed" then
			strContent = replace(strContent, "[U]", "<u>", 1, -1, 1)
			strContent = replace(strContent, "[/U]", "</u>", 1, -1, 1)
		end if
	end if
	
	if instr(1, strContent, "[S]", 1) > 0 then
		strOpen = "[S]"
		strClose = "[/S]"	
		if tag_count(strContent, strOpen, strClose) = "passed" then
			strContent = replace(strContent, "[S]", "<s>", 1, -1, 1)
			strContent = replace(strContent, "[/S]", "</s>", 1, -1, 1)
		end if
	end if
	
	if instr(1, strContent, "[LIST]", 1) > 0 then
		strOpen = "[LIST]"
		strClose = "[/LIST]"	
		if tag_count(strContent, strOpen, strClose) = "passed" then
			strContent = replace(strContent, "[LIST]", "<ul>", 1, -1, 1)
			strContent = replace(strContent, "[LI]", "<li>", 1, -1, 1)
			strContent = replace(strContent, "[/LI]", "</li>", 1, -1, 1)
			strContent = replace(strContent, "[/LIST]", "</ul>", 1, -1, 1)
		end if
	end if
	
	if instr(1, strContent, "[LIST&#61;1]", 1) > 0 then
		strOpen = "[LIST&#61;1]"
		strClose = "[/LIST&#61;1]"	
		if tag_count(strContent, strOpen, strClose) = "passed" then
			strContent = replace(strContent, "[LIST&#61;1]", "<ol>", 1, -1, 1)
			strContent = replace(strContent, "[LI]", "<li>", 1, -1, 1)
			strContent = replace(strContent, "[/LI]", "</li>", 1, -1, 1)
			strContent = replace(strContent, "[/LIST&#61;1]", "</ol>", 1, -1, 1)
		end if
	end if
	
	if instr(1, strContent, "[SPOILER]", 1) > 0 then
		strOpen = "[SPOILER]"
		strClose = "[/SPOILER]"	
		if tag_count(strContent, strOpen, strClose) = "passed" then
			strContent = replace(strContent, "[SPOILER]", "<div class=""spoiler""><div>Spoiler: (highlight to view)</div>", 1, -1, 1)
			strContent = replace(strContent, "[/SPOILER]", "</div>", 1, -1, 1)
		end if
	end if
	
	if instr(1, strContent, "[COLOR&#61;", 1) > 0 then
		strOpen = "[COLOR&#61;"
		strClose = "[/COLOR]"	
		if tag_count(strContent, strOpen, strClose) = "passed" then
			strContent = replace(strContent, "[COLOR&#61;BLACK]", "<span class=""black"">", 1, -1, 1)
			strContent = replace(strContent, "[COLOR&#61;WHITE]", "<span class=""white"">", 1, -1, 1)
			strContent = replace(strContent, "[COLOR&#61;BLUE]", "<span class=""blue"">", 1, -1, 1)
			strContent = replace(strContent, "[COLOR&#61;RED]", "<span class=""red"">", 1, -1, 1)
			strContent = replace(strContent, "[COLOR&#61;GREEN]", "<span class=""green"">", 1, -1, 1)
			strContent = replace(strContent, "[COLOR&#61;YELLOW]", "<span class=""yellow"">", 1, -1, 1)
			strContent = replace(strContent, "[COLOR&#61;ORANGE]", "<span class=""orange"">", 1, -1, 1)
			strContent = replace(strContent, "[COLOR&#61;BROWN]", "<span class=""brown"">", 1, -1, 1)
			strContent = replace(strContent, "[COLOR&#61;MAGENTA]", "<span class=""magenta"">", 1, -1, 1)
			strContent = replace(strContent, "[COLOR&#61;CYAN]", "<span class=""cyan"">", 1, -1, 1)
			strContent = replace(strContent, "[/COLOR]", "</span>", 1, -1, 1)
		end if
	end if
	
	if instr(1, strContent, "[SIZE&#61;", 1) > 0 then
		strOpen = "[SIZE&#61;"
		strClose = "[/SIZE]"	
		if tag_count(strContent, strOpen, strClose) = "passed" then
			strContent = replace(strContent, "[SIZE&#61;1]", "<font size=""1"">", 1, -1, 1)
			strContent = replace(strContent, "[SIZE&#61;2]", "<font size=""2"">", 1, -1, 1)
			strContent = replace(strContent, "[SIZE&#61;3]", "<font size=""3"">", 1, -1, 1)
			strContent = replace(strContent, "[SIZE&#61;4]", "<font size=""4"">", 1, -1, 1)
			strContent = replace(strContent, "[SIZE&#61;5]", "<font size=""5"">", 1, -1, 1)
			strContent = replace(strContent, "[SIZE&#61;6]", "<font size=""6"">", 1, -1, 1)
			strContent = replace(strContent, "[/SIZE]", "</font>", 1, -1, 1)
		end if
	end if
	
	replace_format = strContent

end function

'convert all html formating into bbCode
function revert_format(strContent)
	
	strContent = replace(strContent, "<b>", "[B]")
	strContent = replace(strContent, "</b>", "[/B]")

	strContent = replace(strContent, "<i>", "[I]")
	strContent = replace(strContent, "</i>", "[/I]")
		
	strContent = replace(strContent, "<u>", "[U]")
	strContent = replace(strContent, "</u>", "[/U]")

	strContent = replace(strContent, "<s>", "[S]")
	strContent = replace(strContent, "</s>", "[/S]")
	
	strContent = replace(strContent, "<ul>", "[LIST]")
	strContent = replace(strContent, "</ul>", "[/LIST]")
	
	strContent = replace(strContent, "<ol>", "[LIST=1]")
	strContent = replace(strContent, "</ol>", "[/LIST=1]")
	
	strContent = replace(strContent, "<li>", "[LI]")
	strContent = replace(strContent, "</li>", "[/LI]")
	
	strContent = replace(strContent, "<div class=""spoiler""><span>Spoiler: (highlight to view)</span>", "[SPOILER]")
	strContent = replace(strContent, "</div>", "[/SPOILER]")
	
	strContent = replace(strContent, "<font size=""1"">", "[SIZE&#61;1]")
	strContent = replace(strContent, "<font size=""2"">", "[SIZE&#61;2]")
	strContent = replace(strContent, "<font size=""3"">", "[SIZE&#61;3]")
	strContent = replace(strContent, "<font size=""4"">", "[SIZE&#61;4]")
	strContent = replace(strContent, "<font size=""5"">", "[SIZE&#61;5]")
	strContent = replace(strContent, "<font size=""6"">", "[SIZE&#61;6]")
	strContent = replace(strContent, "</font>", "[/SIZE]")
	
	strContent = replace(strContent, "<span class=""black"">", "[COLOR&#61;BLACK]")
	strContent = replace(strContent, "<span class=""white"">", "[COLOR&#61;WHITE]")
	strContent = replace(strContent, "<span class=""blue"">", "[COLOR&#61;BLUE]")
	strContent = replace(strContent, "<span class=""red"">", "[COLOR&#61;RED]")
	strContent = replace(strContent, "<span class=""green"">", "[COLOR&#61;GREEN]")
	strContent = replace(strContent, "<span class=""yellow"">", "[COLOR&#61;YELLOW]")
	strContent = replace(strContent, "<span class=""orange"">", "[COLOR&#61;ORANGE]")
	strContent = replace(strContent, "<span class=""brown"">", "[COLOR&#61;BROWN]")
	strContent = replace(strContent, "<span class=""magenta"">", "[COLOR&#61;MAGENTA]")
	strContent = replace(strContent, "<span class=""cyan"">", "[COLOR&#61;CYAN]")
	strContent = replace(strContent, "</span>", "[/COLOR]")
	
	revert_format = strContent
	
end function

'replace all [IMG]image location[/IMG] tags within the specified text
function replace_img(strContent)
	
	'dimension variables
	dim intOpen, intClose, strImage, strOriginal, strReplacement
	
	do while instr(1, strContent, "[IMG]", 1) > 0  and InStr(1, strContent, "[/IMG]", 1) > 0
		
		'locate start and end tags
		intOpen = instr(1, strContent, "[IMG]", 1)
		intClose = instr(intOpen, strContent, "[/IMG]", 1) + 6
		
		'isolate complete [IMG] code
		strOriginal = trim(mid(strContent, intOpen, (intClose - intOpen)))
		
		'isolate image URL
		strImage = strOriginal
		strImage = replace(strImage, "[IMG]", "", 1, -1, 1)
		strImage = replace(strImage, "[/IMG]", "", 1, -1, 1)
		
		'filter the image location for any potentially harmful characters
		strImage = replace(strImage, "javascript", " ", 1, -1, 1)
		strImage = replace(strImage, "jscript", " ", 1, -1, 1)
		strImage = replace(strImage, "vbscript", " ", 1, -1, 1)
		strImage = replace(strImage, "mailto", " ", 1, -1, 1)
 		strImage = replace(strImage, "<", " ")
 		strImage = replace(strImage, ">", " ")
		
		'build replacement HTML code
		strReplacement = "<img src=""" & strImage & """ alt=""User posted image"" />"
		
		'replace BB code with HTML code
		strContent = replace(strContent, strOriginal, strReplacement, 1, -1, 1)	
	loop
	
	'output the final altered text
	replace_img = strContent
	
end function

'replace all image links within the specified text
function revert_img(strContent)
	
	'dimension variables
	dim intOpen, iclose, strImage, strOriginal, strReplacement
	
	do while instr(1, strContent, "<img src=""", 1) > 0  and instr(1, strContent, """ alt=""User posted image"" />", 1) > 0
		
		'locate start and end tags
		intOpen = instr(1, strContent, "<img src=""", 1)
		intClose = instr(intOpen, strContent, """ alt=""User posted image"" />", 1) + 28
		
		'isolate comeplete <img> code
		strOriginal = mid(strContent, intOpen, (intClose - intOpen))
		
		'isolate the image URL
		strImage = strOriginal
		strImage = replace(strImage, "<img src=""", "", 1, -1, 1)
		strImage = replace(strImage, """ alt=""User posted image"" />", "", 1, -1, 1)
		
		'build replacement BB code
		strReplacement = "[IMG]" & strImage & "[/IMG]"
		
		'replace HTML code with BB code
		strContent = replace(strContent, strOriginal, strReplacement, 1, -1, 1)	
	loop
	
	'output the final altered text
	revert_img = strContent

end function

'replace all [URL] related tags were applicable
function replace_url(strContent)
	
	'dimension variables
	dim intOpen, intClose, strOriginal, strReplacement, strURL, strText
	
	do while instr(1, strContent, "[URL&#61;", 1) > 0 and instr(1, strContent, "[/URL]", 1) > 0

		'locate the start and end tags
		intOpen = instr(1, strContent, "[URL&#61;", 1)
		intClose = instr(intOpen, strContent, "[/URL]", 1) + 6
		
		if intClose - intOpen <= 5 then
			intClose = intOpen + 5
		end if
		
		'isolate complete [URL= code
		strOriginal = mid(strContent, intOpen, (intClose - intOpen))
		
		'isolate URL
		strURL = strOriginal
		strURL = replace(strURL, "[URL&#61;", "", 1, -1, 1)
		strURL = replace(strURL, "[/URL]", "", 1, -1, 1)
		if instr(1, strURL, "]", 1) <> 0 then
			strURL = left(strURL, instr(1, strURL, "]", 1) - 1)
		end if
		
		'append link protocol if required
		if left(strUrl, 7) <> "http://" and left(strUrl, 6) <> "ftp://" and left(strUrl, 7) <> "mailto:" then
			strUrl = "http://"& strUrl
		end if
		
		'isolate link text
		strText = strOriginal
		strText = replace(strText, "[URL&#61;", "", 1, -1, 1)
		strText = replace(strText, "[/URL]", "", 1, -1, 1)
		strText = replace(strText, strURL, "", 1, -1, 1)
		if strText = "" then
			strText = strURL
		else
			strText = right(strText, len(strText) - 1)
		end if
		
		'filter strUrl for any potentially harmful characters 
		strUrl = replace(strUrl, "javascript", " ", 1, -1, 1)
		strUrl = replace(strUrl, "jscript", " ", 1, -1, 1)
		strUrl = replace(strUrl, "vbscript", " ", 1, -1, 1)
 		strUrl = replace(strUrl, "<", " ")
 		strUrl = replace(strUrl, ">", " ")
		
		'build HTML replacement code
		strReplacement = "<a href=""" & strUrl & """ title=""User posted link"" rel=""external"">" & strText & "</a>"

		'replace BB code with HTML code
		strContent = replace(strContent, strOriginal, strReplacement, 1, -1, 1)
	loop
	
	do while instr(1, strContent, "[URL]", 1) > 0  and instr(1, strContent, "[/URL]", 1) > 0
		
		'locate start and end tags
		intOpen = instr(1, strContent, "[URL]", 1)
		intClose = instr(intOpen, strContent, "[/URL]", 1) + 6
		
		if intClose - intOpen <= 5 then
			intClose = intOpen + 5
		end if
		
		'isolate complete [URL] code
		strOriginal = mid(strContent, intOpen, (intClose - intOpen))
		
		'isolate the URL
		strURL = strOriginal
		strURL = replace(strURL, "[URL]", "", 1, -1, 1)
		strURL = replace(strURL, "[/URL]", "", 1, -1, 1)
		if left(strURL, 7) <> "http://" and left(strReplacement, 6) <> "ftp://" then
			strURL = "http://"& strReplacement
		end if
		
		'filter the url for any potentially harmful characters
		strURL = replace(strURL, "javascript", " ", 1, -1, 1)
		strURL = replace(strURL, "jscript", " ", 1, -1, 1)
		strURL = replace(strURL, "vbscript", " ", 1, -1, 1)
 		strURL = replace(strURL, "<", " ")
 		strURL = replace(strURL, ">", " ")
		
		'build HTML replacement code
		strReplacement = "<a href=""" & strURL & """ title=""User posted link"" rel=""external"">" & strURL & "</a>"
		
		'replace BB code with HTML code
		strContent = replace(strContent, strOriginal, strReplacement, 1, -1, 1)	
	loop
	
	'output altered text
	replace_url = strContent

end function

'replace all hyperlinks with their equivalent bbCode
function revert_url(strContent)

	dim intOpen, intClose, strOriginal, strReplacement, strURL, strText
	
	do while instr(1, strContent, "<a href=""", 1) > 0  and instr(1, strContent, """ title=""User posted link"" rel=""external"">", 1) > 0
		
		'locate start and end tags
		intOpen = instr(1, strContent, "<a href=""", 1)
		intClose = instr(intOpen, strContent, "</a>", 1) + 4
		
		'isolate complete <url> code
		strOriginal = trim(mid(strContent, intOpen, (intClose - intOpen)))
		
		'isolate URL
		strURL = strOriginal
		strURL = left(strOriginal, instr(1, strURL, """ title=""User posted link"" rel=""external"">") -1)
		strURL = replace(strURL, "<a href=""", "", 1, -1, 1)
		
		'isolate link text
		strText = strOriginal
		strText = replace(strText, "<a href="""& strURL &""" title=""User posted link"" rel=""external"">", "", 1, -1, 1)
		strText = replace(strText, "</a>", "", 1, -1, 1)
	
		'build BB replacement code
		if strText = strURL then
			strReplacement = "[URL]" & strURL & "[/URL]"	
		else
			strReplacement = "[URL&#61;" & strURL & "]" & strText & "[/URL]"	
		end if
		
		'replace HTML code with BB code
		strContent = replace(strContent, strOriginal, strReplacement, 1, -1, 1)	
		
	loop

	'output altered text
	revert_url = strContent

end function

'replace all [QUOTE] tags where applicable
function replace_quote(strContent)
	
	'dimension variables
	dim intOpen, intClose, strOriginal, strReplacement
	
	do while instr(1, strContent, "[QUOTE]", 1) > 0  and instr(1, strContent, "[/QUOTE]", 1) > 0
		
		'locate start and end tags
		intOpen = instr(1, strContent, "[QUOTE]", 1)
		intClose = instr(intOpen, strContent, "[/QUOTE]", 1) + 8
		
		'isolate complete [QUOTE] code
		strOriginal = trim(mid(strContent, intOpen, (intClose - intOpen)))
		
		'build the replacement html code
		strReplacement = strOriginal
		strReplacement = replace(strReplacement, "[QUOTE]", "<blockquote>", 1, -1, 1)
		strReplacement = replace(strReplacement, "[/QUOTE]", "</blockquote>", 1, -1, 1)
		
		'replace BB code with HTML code
		strContent = replace(strContent, strOriginal, strReplacement, 1, -1, 1)
	loop
	
	replace_quote = strContent

end function

'replace all <blockuote> tags in the specified text
function revert_quote(strContent)

	'dimension variables
	dim intOpen, intClose, strOriginal, strReplacement
	
	do while instr(1, strContent, "<blockquote>", 1) > 0  and InStr(1, strContent, "</blockquote>", 1) > 0
		
		'locate start and end tags
		intOpen = instr(1, strContent, "<blockquote>", 1)
		intClose = instr(intOpen, strContent, "</blockquote>", 1) + 13
		
		'isolate complete <blockquote> code
		strOriginal = trim(mid(strContent, intOpen, (intClose - intOpen)))
		
		'build replacement BB code
		strReplacement = strOriginal
		strReplacement = replace(strReplacement, "<blockquote>", "[QUOTE]", 1, -1, 1)
		strReplacement = replace(strReplacement, "</blockquote>", "[/QUOTE]", 1, -1, 1)
		
		'replace HTML code with BB code
		strContent = replace(strContent, strOriginal, strReplacement, 1, -1, 1)
	loop
		
	revert_quote = strContent

end function

'remove all <blockuote> tags where applicable
function remove_quote(strContent)
	
	'dimension variables
	dim intOpen, intClose, strOriginal
	
	do while instr(1, strContent, "&lt;blockquote&gt;", 1) > 0  and instr(1, strContent, "&lt;/blockquote&gt;", 1) > 0
		
		'locate start and end tags
		intOpen = instr(1, strContent, "&lt;blockquote&gt;", 1)
		intClose = instr(iintOpen, strContent, "&lt;/blockquote&gt;", 1) + 19
		
		'isolate complete <blockquote> code
		strOriginal = mid(strContent, iintOpen, (iintClose - iintOpen))
		
		'remove <blockquote> 
		strContent = replace(strContent, strOriginal, "", 1, -1, 1)
	loop
		
	remove_quote = strContent

end function
%>