<%
'cleans the specified string of any characters that may cause errors
function clean_text(strContent, iHTML)
	
	if isnull(strContent) = false then
		
		'strip all HTML tags if it has been disabled
		if iHTML = 0 then		
			strContent = strip_HTML(strContent)
		end if
		
		'replace line breaks and white space
		strContent = replace(strContent, "       ", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;")
		strContent = replace(strContent, "      ", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;")
		strContent = replace(strContent, "     ", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;")
		strContent = replace(strContent, "    ", "&nbsp;&nbsp;&nbsp;&nbsp;")
		strContent = replace(strContent, "   ", "&nbsp;&nbsp;&nbsp;")
		strContent = replace(strContent, "  ", " &nbsp;")
		strContent = replace(strContent, vbcrlf, "<br />")
		
		'encodeSQL operators
		strContent = SQL_encode(strContent)
		
		clean_text = strContent
		
	end if
	
end function

'transform any SQL operators to their ascii equivalent
function SQL_encode(strContent)
	
	if isnull(strContent) = false then
		
		'transform sql operators to ascii equivalents
		strContent = replace(strContent, """", "&#34;")
		strContent = replace(strContent, "'", "&#39;")
		strContent = replace(strContent, "+", "&#43;")
		strContent = replace(strContent, "*", "&#42;")
		strContent = replace(strContent, "-", "&#45;")
		strContent = replace(strContent, "=", "&#61;")
		strContent = replace(strContent, "<", "&lt;")
		strContent = replace(strContent, ">", "&gt;")
		strContent = replace(strContent, "%", "&#37;")
		strContent = replace(strContent, "_", "&#95;")
		
		SQL_encode = strContent
		
	end if
	
end function

'tranform ascii characters to their SQL equivalent
function SQL_decode(strContent)
	
	if isnull(strContent) = false then
		
		'transform sql operators
		strContent = replace(strContent, "&#34;", """")
		strContent = replace(strContent, "&#39;", "'")
		strContent = replace(strContent, "&#43;", "+")
		strContent = replace(strContent, "&#42;", "*")
		strContent = replace(strContent, "&#45;", "-")
		strContent = replace(strContent, "&#61;", "=")
		strContent = replace(strContent, "&lt;", "<")
		strContent = replace(strContent, "&gt;", ">")
		strContent = replace(strContent, "&#37;", "%")
		strContent = replace(strContent, "&#95;", "_")
		
		SQL_Decode = strContent
		
	end if
	
end function

'strip all html codes
function strip_HTML(strHTML)
	
	'dimension variables
	dim objRegStrip
	
	'set regular expression
	set objRegStrip = new regexp
	objRegStrip.ignorecase = true
	objRegStrip.global = true
	objRegStrip.pattern = "<(.|\n)+?>"

	'replace all HTML tag matches with the empty string
	strip_HTML = objRegStrip.replace(strHTML, "")
	
	'replace all < and > with &lt; and &gt;
	strip_HTML = replace(strip_HTML, "<", "&lt;")
	strip_HTML = replace(strip_HTML, ">", "&gt;")
	
	'close regular expression
	set objRegStrip = nothing
  
end function

'create date/time string for insertion to database
function db_time(intOffset)
	
	'dimension variables
	dim strDate
	
	'apply time offset
	strDate = dateadd("h", intOffset, now())
	
	db_time = year(strDate)

	if month(strDate) < 10 then
		db_time = db_time & "0" & month(strDate)
	else
		db_time = db_time & month(strDate)
	end if

	if day(strDate) < 10 then
		db_time = db_time & "0" & day(strDate)
	else
		db_time = db_time & day(strDate)
	end if

	if hour(strDate) < 10 then
		db_time = db_time & "0" & hour(strDate)
	else
		db_time = db_time & hour(strDate)
	end if

	if minute(strDate) < 10 then
		db_time = db_time & "0" & minute(strDate)
	else
		db_time = db_time & minute(strDate)
	end if

	if second(strDate) < 10 then
		db_time = db_time & "0" & second(strDate)
	else
		db_time = db_time & second(strDate)
	end if
	
end function

'convert database time from string into date/time format.
function web_time(strTime, strFormat, strLength)
	
	select case strFormat 
		case "UK" 
			select case strLength 
				case "Date" 
					web_time = mid(strTime, 7, 2) & "/" & mid(strTime, 5, 2) & "/" & left(strTime, 4) 
				case "Time" 
					web_time = mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
				case "Full" 
					web_time = mid(strTime, 7, 2) & "/" & mid(strTime, 5, 2) & "/" & left(strTime, 4) & " " & mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
				case else 
					web_time = mid(strTime, 7, 2) & "/" & mid(strTime, 5, 2) & "/" & left(strTime, 4) & " " & mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
			end select 
		case "US" 
			select case strLength 
				case "Date" 
					web_time = mid(strTime, 5, 2) & "/" & mid(strTime, 7, 2) & "/" & left(strTime, 4) 
				case "Time" 
					web_time = mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
				case "Full" 
					web_time = mid(strTime, 5, 2) & "/" & mid(strTime, 7, 2) & "/" & left(strTime, 4) & " " & mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
				case else 
					web_time = mid(strTime, 5, 2) & "/" & mid(strTime, 7, 2) & "/" & left(strTime, 4) & " " & mid(strTime, 9, 2) & ":" & mid(strTime, 11, 2) & ":" & right(strTime, 2) 
			end select 
	end select 
	
end function

'creates a date string offset by duration of type interval to compare with database times
function search_time(intInterval, intDuration)
	
	'valid intervals are as follows, speach marks are required:
	'year: "yyyy"
	'month: "m"
	'day: "d"
	'hour: "h"
	'minute: "n"
	'second: "s"
	
	'dimension variables
	dim strDate
	
	'apply time offset
	strDate = dateadd("h", intBlogTimeOffset, now())
	
	search_time = year(dateadd(intInterval, intDuration, strDate))

	if month(dateadd(intInterval, intDuration, strDate)) < 10 then
		search_time = search_time & "0" & month(dateadd(intInterval, intDuration, strDate))
	else
		search_time = search_time & month(dateadd(intInterval, intDuration, strDate))
	end if

	if day(dateadd(intInterval, intDuration, strDate)) < 10 then
		search_time = search_time & "0" & day(dateadd(intInterval, intDuration, strDate))
	else
		search_time = search_time & day(dateadd(intInterval, intDuration, strDate))
	end if

	if hour(dateadd(intInterval, intDuration, strDate)) < 10 then
		search_time = search_time & "0" & hour(dateadd(intInterval, intDuration, strDate))
	else
		search_time = search_time & hour(dateadd(intInterval, intDuration, strDate))
	end if

	if minute(dateadd(intInterval, intDuration, strDate)) < 10 then
		search_time = search_time & "0" & minute(dateadd(intInterval, intDuration, strDate))
	else
		search_time = search_time & minute(dateadd(intInterval, intDuration, strDate))
	end if

	if second(dateadd(intInterval, intDuration, strDate)) < 10 then
		search_time = search_time & "0" & second(dateadd(intInterval, intDuration, strDate))
	else
		search_time = search_time & second(dateadd(intInterval, intDuration, strDate))
	end if
	
end function

'validates email addresses using regular expressions
function validate_email(strEmail)

    dim objRegExpr
	 
    set objRegExpr = new regexp
    objRegExpr.Pattern = "^[a-zA-Z0-9][\w\.-]*[a-zA-Z0-9]@[\w-\.]*[a-zA-Z0-9]\.[a-zA-Z]{2,7}$"
    objRegExpr.Global = true
    objRegExpr.IgnoreCase = false
	 
    validate_email = objRegExpr.test(strEmail)
	 
    set objRegExpr = nothing
	 
end function

'send email using the specified email component
function send_email(strEmailTo, strEmailFrom, strEmailFromName, strEmailSubject, strEmailBody)
	dim objMail
	
	'check valid email address was specified
	if strEmailTo <> ""  and validate_email(strEmailTo) = true then
	
		select case strBlogEmailComponent
			case "CDOSYS"
				set objMail = server.createobject("CDO.Message")
				objMail.to = strEmailTo
				objMail.From = strEmailFromName &"<"& strEmailFrom &">"
				objMail.Subject = strEmailSubject
				objMail.HtmlBody = strEmailBody
				objMail.Send()
				set objMail = nothing
			case "CDONTS"
				set objMail = server.createobject("CDONTS.NewMail")
				objMail.From = strEmailFromName &"<"& strEmailFrom &">"
				objMail.To = strEmailTo
				objMail.Subject = strEmailSubject
				objMail.Body = strEmailBody
				objMail.BodyFormat = 0
				objMail.MailFormat = 0
				objMail.Send
				set objMail = nothing
			case "ASPEMAIL"
				set objMail = server.createobject("persits.mailsender")
				objMail.Host = strBlogEmailHost
				objMail.From = strEmailFrom
				objMail.FromName = strEmailFromName
				objMail.AddAddress strEmailTo
				objMail.Subject = strEmailSubject
				objMail.Body = strEmailBody
				objMail.IsHTML = true 
				objMail.Send
				set objMail = nothing
			case "JMAIL"
				 set objMail = server.createobject("JMail.Message")
				 objMail.From = strEmailFrom
				 objMail.FromName = strEmailFromName
				 objMail.AddRecipient strEmailTo
				 objMail.Subject = strEmailSubject
				 objMail.HTMLBody = strEmailBody
				 objMail.Send(strBlogEmailHost)
				 set objMail = Nothing
				
		end select
	
	end if
	
end function

'validate user dependant on their user level
function level_check(intUserLevel)
	
	'check user is logged in
	if session("FB_UserLevel") = "" then
		
		response.redirect(strBlogLocation &"/error.asp?Type=Administration&Error=Logged&Redirect=/Admin/login.asp")
		
	else
		
		'check user has sufficient permissions
		if session("FB_UserLevel") < intUserLevel then
			
			response.redirect(strBlogLocation &"/error.asp?Type=Administration&Error=Permissions&Redirect=/Admin")
			
		end if
		
	end if
	
end function
%>